==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/netadm/netadm.pm <==
/* _dict.cc 25/11/97 00.14.20 */
/* cluster.cc 08/10/98 23.25.44 */
PUBLIC CLUSTER::CLUSTER (void);
PUBLIC CLUSTER::CLUSTER (const char *_id);
PUBLIC int CLUSTER::publish (void);
PRIVATE void CLUSTER::update_subsyss (SSTRINGS&tbsys,
	 char tbsys_sel[]);
PUBLIC int CLUSTER::edit (void);
PUBLIC CLUSTERS::CLUSTERS (void);
PUBLIC CLUSTER *CLUSTERS::getitem (int no)const;
PRIVATE void CLUSTER::delinfo (void);
PUBLIC void CLUSTER::write (void);
PUBLIC int CLUSTERS::write (void);
PUBLIC int CLUSTERS::publish (const char *tree);
PUBLIC int CLUSTERS::edit (void);
/* export.cc 09/03/99 10.29.48 */
PRIVATE int CLUSTER::exportone (const char *member, const char *pass);
PUBLIC int CLUSTER::exportall (void);
/* internal.cc 24/11/97 23.50.20 */
PUBLIC NETADM_HELP_FILE::NETADM_HELP_FILE (const char *fname);
/* netadm.cc 06/01/99 21.25.22 */
PUBLIC MODULE_NETADM::MODULE_NETADM (void);
PUBLIC void MODULE_NETADM::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_NETADM::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_NETADM::dohtml (const char *key);
PUBLIC void MODULE_NETADM::usage (SSTRINGS&tb);
PUBLIC int MODULE_NETADM::execmain (int argc, char *argv[]);
/* remadm.cc 05/01/98 23.40.26 */
/* repeat.cc 18/11/97 19.48.40 */
/* slave.cc 02/12/97 01.35.52 */
PUBLIC SLAVE_FCTL::SLAVE_FCTL (int _fdin);
PUBLIC int SLAVE_FCTL::readlen (void *buf, int size, bool linemode);
PUBLIC int SLAVE_FCTL::readlen (void *buf, int size);
PUBLIC int SLAVE_FCTL::readok (void *buf, int size);
PUBLIC int SLAVE_FCTL::gets (char *buf, int size);
PUBLIC SSTREAM_DATA::SSTREAM_DATA (FILE *fout);
PUBLIC void SSTREAM_DATA::puts (const char *s);
/* testsend.cc 18/11/97 19.22.30 */
/* tree.cc 01/12/97 23.34.26 */

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/netadm/netadm.pm <==
/* _dict.cc 25/11/1997 00.14.20 */
/* cluster.cc 08/08/2000 22.13.12 */
PUBLIC CLUSTER::CLUSTER (void);
PUBLIC CLUSTER::CLUSTER (const char *_id);
PUBLIC int CLUSTER::publish (void);
PRIVATE void CLUSTER::update_subsyss (SSTRINGS&tbsys,
	 char tbsys_sel[]);
PUBLIC int CLUSTER::edit (void);
PUBLIC CLUSTERS::CLUSTERS (void);
PUBLIC CLUSTER *CLUSTERS::getitem (int no)const;
PRIVATE void CLUSTER::delinfo (void);
PUBLIC void CLUSTER::write (void);
PUBLIC int CLUSTERS::write (void);
PUBLIC int CLUSTERS::publish (const char *tree);
PUBLIC int CLUSTERS::edit (void);
/* export.cc 11/08/2000 15.12.12 */
PRIVATE int CLUSTER::exportone (const char *member,
	 const char *pass,
	 const char *cmd);
PUBLIC int CLUSTER::exportall (const char *defcmd);
/* internal.cc 24/11/1997 23.50.20 */
PUBLIC NETADM_HELP_FILE::NETADM_HELP_FILE (const char *fname);
/* netadm.cc 28/08/2000 18.13.50 */
PUBLIC MODULE_NETADM::MODULE_NETADM (void);
PUBLIC void MODULE_NETADM::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_NETADM::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_NETADM::dohtml (const char *key);
PUBLIC void MODULE_NETADM::usage (SSTRINGS&tb);
PUBLIC int MODULE_NETADM::execmain (int argc, char *argv[], bool);
/* remadm.cc 05/01/1998 23.40.26 */
/* repeat.cc 18/11/1997 19.48.40 */
/* slave.cc 02/12/1997 01.35.52 */
PUBLIC SLAVE_FCTL::SLAVE_FCTL (int _fdin);
PUBLIC int SLAVE_FCTL::readlen (void *buf, int size, bool linemode);
PUBLIC int SLAVE_FCTL::readlen (void *buf, int size);
PUBLIC int SLAVE_FCTL::readok (void *buf, int size);
PUBLIC int SLAVE_FCTL::gets (char *buf, int size);
PUBLIC SSTREAM_DATA::SSTREAM_DATA (FILE *fout);
PUBLIC void SSTREAM_DATA::puts (const char *s);
/* testsend.cc 18/11/1997 19.22.30 */
/* tree.cc 01/12/1997 23.34.26 */
